@@ -23,6 +23,7 @@ package cmd
 import (
 	"bufio"
 	"bytes"
+	"errors"
 	"fmt"
 	"io"
 	"os"
@@ -39,6 +40,7 @@ import (
 
 type reportConfig struct {
 	style                     string
+	useIndentLines            bool
 	ignoreOrderChanges        bool
 	ignoreWhitespaceChanges   bool
 	kubernetesEntityDetection bool
@@ -60,6 +62,7 @@ type reportConfig struct {
 
 var defaults = reportConfig{
 	style:                     "human",
+	useIndentLines:            true,
 	ignoreOrderChanges:        false,
 	ignoreWhitespaceChanges:   false,
 	kubernetesEntityDetection: true,
@@ -96,6 +99,7 @@ func applyReportOptionsFlags(cmd *cobra.Command) {
 
 	// Main output preferences
 	cmd.Flags().StringVarP(&reportOptions.style, "output", "o", defaults.style, "specify the output style, supported styles: human, brief, github, gitlab, gitea")
+	cmd.Flags().BoolVar(&reportOptions.useIndentLines, "use-indent-lines", defaults.useIndentLines, "use indent lines in the output")
 	cmd.Flags().BoolVarP(&reportOptions.omitHeader, "omit-header", "b", defaults.omitHeader, "omit the dyff summary header")
 	cmd.Flags().BoolVarP(&reportOptions.exitWithCode, "set-exit-code", "s", defaults.exitWithCode, "set program exit code, with 0 meaning no difference, 1 for differences detected, and 255 for program error")
 
@@ -151,7 +155,7 @@ func (w *OutputWriter) WriteInplace(filename string) error {
 	}
 
 	// Write the buffered output to the provided input file (override in place)
-	bufWriter.Flush()
+	_ = bufWriter.Flush()
 	if err := os.WriteFile(filename, buf.Bytes(), 0644); err != nil {
 		return fmt.Errorf("failed to overwrite %s in place: %w", humanReadableFilename(filename), err)
 	}
@@ -176,10 +180,10 @@ func (w *OutputWriter) write(writer io.Writer, filename string) error {
 			if err != nil {
 				return err
 			}
-			fmt.Fprintf(writer, "%s\n", output)
+			_, _ = fmt.Fprintln(writer, output)
 
 		case w.PlainMode && w.OutputStyle == "yaml":
-			fmt.Fprintln(writer, "---")
+			_, _ = fmt.Fprintln(writer, "---")
 			encoder := yamlv3.NewEncoder(writer)
 			encoder.SetIndent(2)
 
@@ -196,14 +200,14 @@ func (w *OutputWriter) write(writer io.Writer, filename string) error {
 			if err != nil {
 				return err
 			}
-			fmt.Fprintf(writer, "%s\n", output)
+			_, _ = fmt.Fprintln(writer, output)
 
 		case w.OutputStyle == "yaml":
 			output, err := neat.NewOutputProcessor(!w.OmitIndentHelper, true, &neat.DefaultColorSchema).ToYAML(document)
 			if err != nil {
 				return err
 			}
-			fmt.Fprintf(writer, "%s\n", output)
+			_, _ = fmt.Fprintln(writer, output)
 		}
 	}
 
@@ -217,6 +221,7 @@ func writeReport(cmd *cobra.Command, report dyff.Report) error {
 		reportWriter = &dyff.HumanReport{
 			Report:                report,
 			Indent:                2,
+			UseIndentLines:        reportOptions.useIndentLines,
 			DoNotInspectCerts:     reportOptions.doNotInspectCerts,
 			NoTableStyle:          reportOptions.noTableStyle,
 			OmitHeader:            reportOptions.omitHeader,
@@ -234,6 +239,7 @@ func writeReport(cmd *cobra.Command, report dyff.Report) error {
 			HumanReport: dyff.HumanReport{
 				Report:                report,
 				Indent:                0,
+				UseIndentLines:        reportOptions.useIndentLines,
 				DoNotInspectCerts:     reportOptions.doNotInspectCerts,
 				NoTableStyle:          true,
 				OmitHeader:            true,
@@ -252,6 +258,7 @@ func writeReport(cmd *cobra.Command, report dyff.Report) error {
 			HumanReport: dyff.HumanReport{
 				Report:                report,
 				Indent:                0,
+				UseIndentLines:        reportOptions.useIndentLines,
 				DoNotInspectCerts:     reportOptions.doNotInspectCerts,
 				NoTableStyle:          true,
 				OmitHeader:            true,
@@ -270,6 +277,7 @@ func writeReport(cmd *cobra.Command, report dyff.Report) error {
 			HumanReport: dyff.HumanReport{
 				Report:                report,
 				Indent:                0,
+				UseIndentLines:        reportOptions.useIndentLines,
 				DoNotInspectCerts:     reportOptions.doNotInspectCerts,
 				NoTableStyle:          true,
 				OmitHeader:            true,
@@ -286,7 +294,7 @@ func writeReport(cmd *cobra.Command, report dyff.Report) error {
 		}
 
 	default:
-		return fmt.Errorf("unknown output style %s: %w", reportOptions.style, fmt.Errorf(cmd.UsageString()))
+		return fmt.Errorf("unknown output style %s: %w", reportOptions.style, errors.New(cmd.UsageString()))
 	}
 
 	if err := reportWriter.WriteReport(os.Stdout); err != nil {
