@@ -831,6 +831,19 @@ listY: [ Yo, Yo, Yo ]
 
 				Expect(report.ExcludeRegexp("/does/not/exist")).To(BeEquivalentTo(report))
 			})
+
+			It("should ignore changes in values", func() {
+				report := dyff.Report{Diffs: []dyff.Diff{
+					singleDiff("/yaml/map/add", dyff.ADDITION, nil, "added"),
+					singleDiff("/yaml/map/removed", dyff.REMOVAL, nil, "removed"),
+					singleDiff("/yaml/map/changed", dyff.MODIFICATION, "foobar", "barfoo"),
+				}}
+
+				Expect(report.IgnoreValueChanges()).To(BeEquivalentTo(dyff.Report{Diffs: []dyff.Diff{
+					singleDiff("/yaml/map/add", dyff.ADDITION, nil, "added"),
+					singleDiff("/yaml/map/removed", dyff.REMOVAL, nil, "removed"),
+				}}))
+			})
 		})
 
 		Context("change root for comparison", func() {
@@ -1111,6 +1124,20 @@ b: bar
 				Expect(results).ToNot(BeNil())
 				Expect(results.Diffs).To(HaveLen(0))
 			})
+
+			It("should produce deterministic results when lists with non-standard identifiers are compared", func() {
+				from, to, err := ytbx.LoadFiles(assets("issues", "issue-525", "from.yaml"), assets("issues", "issue-525", "to.yaml"))
+				Expect(err).To(BeNil())
+				Expect(from).ToNot(BeNil())
+				Expect(to).ToNot(BeNil())
+
+				for range 100 {
+					results, err := dyff.CompareInputFiles(from, to)
+					Expect(err).NotTo(HaveOccurred())
+					Expect(results).ToNot(BeNil())
+					Expect(results.Diffs).To(HaveLen(4))
+				}
+			})
 		})
 	})
 })
