@@ -26,8 +26,10 @@ import (
 	"strings"
 
 	"github.com/gonvenience/bunt"
+	"github.com/gonvenience/idem"
 	"github.com/gonvenience/text"
 	"github.com/gonvenience/ytbx"
+
 	"github.com/mitchellh/hashstructure"
 	yamlv3 "gopkg.in/yaml.v3"
 )
@@ -40,6 +42,7 @@ type compareSettings struct {
 	IgnoreOrderChanges                       bool
 	IgnoreWhitespaceChanges                  bool
 	KubernetesEntityDetection                bool
+	DetectRenames                            bool
 	AdditionalIdentifiers                    []string
 }
 
@@ -86,6 +89,13 @@ func KubernetesEntityDetection(value bool) CompareOption {
 	}
 }
 
+// DetectRenames enabled detection of renames so that it correlates two entries based on their identifier field
+func DetectRenames(value bool) CompareOption {
+	return func(settings *compareSettings) {
+		settings.DetectRenames = value
+	}
+}
+
 // CompareInputFiles is one of the convenience main entry points for comparing
 // objects. In this case the representation of an input file, which might
 // contain multiple documents. It returns a report with the list of differences.
@@ -136,11 +146,12 @@ func CompareInputFiles(from ytbx.InputFile, to ytbx.InputFile, compareOptions ..
 			from.Documents, from.Names = fromDocs, fromNames
 			to.Documents, to.Names = toDocs, toNames
 
-			// Compare the document nodes, in case of an error it will fall back to the default
-			// implementation and continue to compare the files without any special semantics
-			if result, err := cmpr.documentNodes(from, to); err == nil {
-				return Report{from, to, result}, nil
+			// Compare the document nodes
+			result, err := cmpr.documentNodes(from, to)
+			if err != nil {
+				return Report{}, fmt.Errorf("comparing Kubernetes resources: %w", err)
 			}
+			return Report{from, to, result}, nil
 		}
 	}
 
@@ -283,8 +294,8 @@ func (compare *compare) documentNodes(from, to ytbx.InputFile) ([]Diff, error) {
 		return nil, err
 	}
 
-	removals := []*yamlv3.Node{}
-	additions := []*yamlv3.Node{}
+	var removals []doc
+	var additions []doc
 
 	for _, name := range fromNames {
 		var fromItem = fromLookUpMap[name]
@@ -295,16 +306,14 @@ func (compare *compare) documentNodes(from, to ytbx.InputFile) ([]Diff, error) {
 				followAlias(fromItem.node),
 				followAlias(toItem.node),
 			)
-
 			if err != nil {
 				return nil, err
 			}
 
 			result = append(result, diffs...)
-
 		} else {
 			// `from` contain the `key`, but `to` does not -> removal
-			removals = append(removals, fromItem.node)
+			removals = append(removals, fromItem)
 		}
 	}
 
@@ -312,55 +321,98 @@ func (compare *compare) documentNodes(from, to ytbx.InputFile) ([]Diff, error) {
 		var toItem = toLookUpMap[name]
 		if _, ok := fromLookUpMap[name]; !ok {
 			// `to` contains a `key` that `from` does not have -> addition
-			additions = append(additions, toItem.node)
+			additions = append(additions, toItem)
 		}
 	}
 
-	diff := Diff{Details: []Detail{}}
+	candidateName := func(mappingNode *yamlv3.Node) string {
+		name, _ := k8sItem.Name(mappingNode)
+		return name
+	}
 
-	if len(removals) > 0 {
-		diff.Details = append(diff.Details,
-			Detail{
+	changes := idem.NewDocumentChanges(
+		mapItemsToSlice(removals, func(d doc) *idem.RenameCandidate {
+			return idem.NewRenameCandidate(
+				candidateName(d.node),
+				&ytbx.Path{Root: &from, DocumentIdx: d.idx},
+				d.node,
+			)
+		}),
+		mapItemsToSlice(additions, func(d doc) *idem.RenameCandidate {
+			return idem.NewRenameCandidate(
+				candidateName(d.node),
+				&ytbx.Path{Root: &to, DocumentIdx: d.idx},
+				d.node,
+			)
+		}),
+	)
+
+	if compare.settings.DetectRenames {
+		if err := idem.DetectRenames(changes, nil); err != nil {
+			return nil, err
+		}
+	}
+
+	// Push rename detection results
+	for _, modified := range changes.ModifiedPairs() {
+		diffs, err := compare.objects(
+			*modified.To.Path,
+			followAlias(modified.From.Doc),
+			followAlias(modified.To.Doc),
+		)
+		if err != nil {
+			return nil, err
+		}
+		result = append(result, diffs...)
+
+		// Exclude from order change calculation
+		fromNames, _ = reject(fromNames, modified.From.Name())
+		toNames, _ = reject(toNames, modified.To.Name())
+	}
+
+	for _, removal := range changes.DeletedList {
+		result = append(result, Diff{
+			Path: removal.Path,
+			Details: []Detail{{
 				Kind: REMOVAL,
 				From: &yamlv3.Node{
 					Kind:    yamlv3.DocumentNode,
-					Content: removals,
+					Content: []*yamlv3.Node{removal.Doc},
 				},
 				To: nil,
-			},
-		)
+			}},
+		})
 	}
 
-	if len(additions) > 0 {
-		diff.Details = append(diff.Details,
-			Detail{
+	for _, addition := range changes.AddedList {
+		result = append(result, Diff{
+			Path: addition.Path,
+			Details: []Detail{{
 				Kind: ADDITION,
 				From: nil,
 				To: &yamlv3.Node{
 					Kind:    yamlv3.DocumentNode,
-					Content: additions,
+					Content: []*yamlv3.Node{addition.Doc},
 				},
-			},
-		)
+			}},
+		})
 	}
 
 	if !compare.settings.IgnoreOrderChanges && len(fromNames) == len(toNames) {
 		for i := range fromNames {
 			if fromNames[i] != toNames[i] {
-				diff.Details = append(diff.Details, Detail{
-					Kind: ORDERCHANGE,
-					From: AsSequenceNode(fromNames...),
-					To:   AsSequenceNode(toNames...),
+				result = append(result, Diff{
+					Details: []Detail{{
+						Kind: ORDERCHANGE,
+						From: AsSequenceNode(fromNames...),
+						To:   AsSequenceNode(toNames...),
+					}},
 				})
 				break
 			}
 		}
 	}
 
-	if len(diff.Details) > 0 {
-		result = append([]Diff{diff}, result...)
-	}
-
 	return result, nil
 }
 
@@ -894,7 +946,15 @@ func (compare *compare) getNonStandardIdentifierFromNamedLists(listA, listB *yam
 	counterA := createKeyCountMap(listA)
 	counterB := createKeyCountMap(listB)
 
-	for keyA, countA := range counterA {
+	// Sort the keys to ensure deterministic order
+	keysA := make([]string, 0, len(counterA))
+	for keyA := range counterA {
+		keysA = append(keysA, keyA)
+	}
+	sort.Strings(keysA)
+
+	for _, keyA := range keysA {
+		countA := counterA[keyA]
 		if countB, ok := counterB[keyA]; ok {
 			if countA == listALength && countB == listBLength && countA > compare.settings.NonStandardIdentifierGuessCountThreshold {
 				return &singleField{keyA}
